Installation of pywbem
======================

To install the latest released version of pywbem on Linux:

* Install the prerequisite OS-level packages:

  * Download the
    [pywbem_os_setup.sh](https://pywbem.readthedocs.io/en/stable/_downloads/pywbem_os_setup.sh)
    script

  * Execute that script:

        $ ./pywbem_os_setup.sh

* With your target Python environment active, install pywbem:

      $ pip install pywbem

  This will also install any prerequisite Python packages.

For more details, installation on other operating systems, and alternative
ways to install, see the
[Installation section](https://pywbem.readthedocs.io/en/stable/intro.html#installation)
in the pywbem documentation.
